@@ -526,11 +526,13 @@ class DynamicSetting(object):
             healthy = True
             reason = None
 
+        download_time_iso = self.download_time.isoformat() if not self.download_time is None else None
+
         d = {
             'healthy': healthy,
             'slug': self.slug,
             'load_time': self.load_time.isoformat(),
-            'download_time': self.download_time.isoformat(),
+            'download_time': download_time_iso,
             'age': str(self.age),
             'max_age': str(self.max_age),
             'allow_fallback': self.fallback_allowed,
@@ -539,6 +541,7 @@ class DynamicSetting(object):
             'version': self.version,
             'health_relevant': self.health_relevant
         }
+
         if not healthy:
             d.update({'reason': reason})
         return d
